<?xml version='1.0' encoding='UTF-8'?>
<!--
|   This stylesheet transforms the CDM Ruleframe classification.xml to
|   a web page where users can classify their business rules until
|   the rule is uniquely classified.
|   Two named templates are used to render either a questionaire with radio
|   buttons (template questionaire) or the final rule class (template showResult).
|   The portlet look-and-feel of the page is coded in tpl-amisLAF.xml
|
|   Author: Harm Verschuren, Feb. 2004
+-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" encoding="UTF-8"/>
  <xsl:strip-space elements="*"/>
  <xsl:include href="tpl-amisLAF.xsl"/>
  <!--
  |    Parameter rule holds value of classification to be rendered.
  |    If rule is empty the first classifiction rule is rendered.
  +-->
  <xsl:param name="rule">
    <xsl:choose>
      <xsl:when test="boolean(string(/page/choice)) = true()">
        <xsl:value-of select="/page/choice"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>1</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:param>

  <!-- this named template renders the final result (classification of the rule) -->
  <xsl:template name="showResult">
    <xsl:call-template name="portlet">
      <xsl:with-param name="title"/>
      <xsl:with-param name="contents">
        <h3>Your business rule is classified as:
          <p/>
          <font color="blue">
            <xsl:value-of select="/page/autorisationrules/rule[@num=$rule]/title"/>
          </font>
        </h3>
        <hr/>
        <form method="post">
          <input type="submit" class="inpsubmit" value="Start new classification"/>
        </form>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <!-- this named template renders the questionaire -->
  <xsl:template name="questionaire">
    <xsl:call-template name="portlet">
      <xsl:with-param name="title" select="title"/>
      <xsl:with-param name="contents">
        <xsl:value-of select="statement"/>
        <form method="post">
          <table cellpadding="5">
            <tr class="TR">
              <td>
                <xsl:apply-templates select="yes"/>
              </td>
            </tr>
            <tr class="TR">
              <td>
                <xsl:apply-templates select="no"/>
              </td>
            </tr>
            <tr class="TR">
              <td span="2">
                <input type="submit" class="inpsubmit" value="Enter your choice"/>
              </td>
            </tr>
          </table>
        </form>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="/">
    <html>
      <head>
        <xsl:call-template name="html-head">
          <xsl:with-param name="title">CDMRuleframe classification of business rules</xsl:with-param>
          <xsl:with-param name="stylesheet">cdmruleframe.css</xsl:with-param>
        </xsl:call-template>
      </head>
      <body>
        <xsl:apply-templates select="page/autorisationrules"/>
      </body>
    </html>
  </xsl:template>

  <!--
  |   Render only that rule with the right number = choice number
  +-->
  <xsl:template match="autorisationrules">
    <xsl:apply-templates select="rule[@num=$rule]"/>
  </xsl:template>

  <xsl:template match="rule">
    <xsl:choose>
      <!--
      |    Whenever the chosen statement must be answered, template questionaire is called.
      |    When no statement is present, the rule is classified and the result must be shown
      -->
      <xsl:when test="boolean(string(/page/autorisationrules/rule[@num=$rule]/statement))=true()">
        <xsl:call-template name="questionaire"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="showResult"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- render radio button -->
  <xsl:template match="yes|no">
    <input type="radio" name="choice" class="inpradio">
      <xsl:attribute name="value">
        <xsl:value-of select="./@goto"/>
      </xsl:attribute>
      <xsl:value-of select="name()"/>
    </input>
  </xsl:template>

  <!-- no not render the choice element -->
  <xsl:template match="choice"/>
</xsl:stylesheet>
